@@ -51,20 +51,22 @@ sub json_to_hash {
 
 sub prepare_info {
     my ( $opt, $info, $ex, $video_id ) = @_;
-    if ( $info->{$ex}{$video_id}{upload_date} && $info->{$ex}{$video_id}{upload_date} =~ /^(\d{4})(\d{2})(\d{2})\z/ ) {
-        $info->{$ex}{$video_id}{upload_date}     = $1 . '-' . $2 . '-' . $3;
-        $info->{$ex}{$video_id}{upload_datetime} = $1 . '-' . $2 . '-' . $3 . 'T00:00:00';
-    }
-    if ( $info->{$ex}{$video_id}{published} && $info->{$ex}{$video_id}{published} =~ /^(\d\d\d\d-\d\d-\d\d)T(\d\d:\d\d:\d\d)/ ) {
-        $info->{$ex}{$video_id}{upload_date} = $1;
-        $info->{$ex}{$video_id}{upload_datetime} = $1 . 'T' . $2;
+    if ( $info->{$ex}{$video_id}{upload_date} ) {
+        if ( $info->{$ex}{$video_id}{upload_date} =~ /^(\d{4})(\d{2})(\d{2})\z/ ) {
+            $info->{$ex}{$video_id}{upload_date}     = $1 . '-' . $2 . '-' . $3;
+            $info->{$ex}{$video_id}{upload_datetime} = $1 . '-' . $2 . '-' . $3 . 'T00:00:00';
+        }
+        if ( $info->{$ex}{$video_id}{upload_date} =~ /^(\d\d\d\d-\d\d-\d\d)T(\d\d:\d\d:\d\d)/ ) {
+            $info->{$ex}{$video_id}{upload_date} = $1;
+            $info->{$ex}{$video_id}{upload_datetime} = $1 . 'T' . $2;
+        }
     }
     if ( ! $info->{$ex}{$video_id}{upload_date} && $info->{$ex}{$video_id}{upload_date_rel} ) {
         $info->{$ex}{$video_id}{upload_date} = $info->{$ex}{$video_id}{upload_date_rel};
     }
     $info->{$ex}{$video_id}{title}           ||= time();
     $info->{$ex}{$video_id}{duration}        ||= '-:--:--';
-    $info->{$ex}{$video_id}{upload_date}     ||= exists $info->{$ex}{$video_id}{upload_date_rel} ? '---------' : '0000-00-00';
+    $info->{$ex}{$video_id}{upload_date}     ||= '';
     $info->{$ex}{$video_id}{upload_datetime} ||= '0000-00-00T00:00:00';
     $info->{$ex}{$video_id}{playlist_id} //= '';
     $info->{$ex}{$video_id}{uploader_id} //= $info->{$ex}{$video_id}{uploader} // '';
