@@ -8,7 +8,6 @@ use 5.010000;
 use Exporter qw( import );
 our @EXPORT_OK = qw( download_youtube );
 
-use Fcntl                 qw( LOCK_EX SEEK_END ); # ###
 use File::Basename        qw( basename );
 use File::Spec::Functions qw( catfile );
 use Time::HiRes           qw( gettimeofday tv_interval );
@@ -273,26 +272,6 @@ sub _return_callback {
 }
 
 
-sub _log_info { # ###
-    my ( $opt, $info, $ex, $video_id, $fmt ) = @_;
-    my ( $sec, $min, $hour, $mday, $mon, $year ) = localtime;
-    my $uploader_id = $info->{$ex}{$video_id}{uploader_id};
-    my $playlist_id = $info->{$ex}{$video_id}{playlist_id};
-    my $id = $ex eq 'youtube' ? $video_id : $ex . ' ' . $video_id;
-    my $log_str = sprintf( "%04d-%02d-%02d %02d:%02d", $year + 1900, $mon + 1, $mday, $hour, $min )
-        . '>  ' . sprintf( "%11s", $id )
-        . ' | ' . ( length $uploader_id ? $uploader_id : 'xxxxx' )
-        . ' | ' . ( length $playlist_id ? $playlist_id : '-----' )
-        . ' | ' . ( $info->{$ex}{$video_id}{upload_date} )
-        . '   ' . basename( $info->{$ex}{$video_id}{file_name}{$fmt} );
-    open my $log, '>>:encoding(UTF-8)', encode_fs( $opt, $opt->{log_file} ) or die $!;
-    flock $log, LOCK_EX     or die $!;
-    seek  $log, 0, SEEK_END or die $!;
-    say   $log $log_str;
-    close $log or die $!;
-}
-
-
 sub _archive_download {
     my ( $opt, $info, $ex, $video_id, $fmt ) = @_;
     my $filename = catfile $opt->{archive_dir}, sprintf 'downloads_%s.json', $ex;
