@@ -166,8 +166,8 @@ sub sec_to_time {
 
 
 sub write_json {
-    my ( $opt, $file, $h_ref ) = @_;
-    my $json = JSON->new->pretty->canonical->utf8->encode( $h_ref );
+    my ( $opt, $file, $ref ) = @_;
+    my $json = JSON->new->pretty->canonical->utf8->encode( $ref );
     open my $fh, '>', encode_fs( $opt, $file ) or die encode_fs( $opt, $file ) . " $!";
     flock $fh, LOCK_EX     or die $!;
     seek  $fh, 0, SEEK_END or die $!;
