@@ -20,8 +20,8 @@ sub __read_history_files {  #### use this after some time ####
     $opt->{sticky}  = {};
     $opt->{history} = {};
     if ( $opt->{max_size_history} ) {
-        $opt->{sticky}  = read_json( $opt, $opt->{sticky_file} )  if -e $opt->{sticky_file};
-        $opt->{history} = read_json( $opt, $opt->{history_file} ) if -e $opt->{history_file};
+        $opt->{sticky}  = read_json( $opt, $opt->{sticky_file} )  // {}  if -e $opt->{sticky_file};
+        $opt->{history} = read_json( $opt, $opt->{history_file} ) // {} if -e $opt->{history_file};
     }
 }
 sub read_history_files {  #### keep this for some time ####
@@ -33,10 +33,10 @@ sub read_history_files {  #### keep this for some time ####
     $opt->{history} = {};
     if ( $opt->{max_size_history} ) {
         if ( -e $opt->{sticky_file} ) {
-            $opt->{sticky} = read_json( $opt, $opt->{sticky_file} );
+            $opt->{sticky} = read_json( $opt, $opt->{sticky_file} ) // {};
         }
         elsif ( -e $old_sticky_file ) {
-            $opt->{sticky} = read_json( $opt, $old_sticky_file );
+            $opt->{sticky} = read_json( $opt, $old_sticky_file ) // {};
             for my $url ( keys %{$opt->{sticky}} ) {
                 $opt->{sticky}{$url}{uploader}    =         delete $opt->{sticky}{$url}{channel}       if $opt->{sticky}{$url}{channel};
                 $opt->{sticky}{$url}{uploader_id} =         delete $opt->{sticky}{$url}{channel_id}    if $opt->{sticky}{$url}{channel_id};
@@ -57,10 +57,10 @@ sub read_history_files {  #### keep this for some time ####
         unlink $old_sticky_file or warn $!;
         }
         if ( -e $opt->{history_file} ) {
-            $opt->{history} = read_json( $opt, $opt->{history_file} );
+            $opt->{history} = read_json( $opt, $opt->{history_file} ) // {};
         }
         elsif ( -e $old_history_file ) {
-            $opt->{history} = read_json( $opt, $old_history_file );
+            $opt->{history} = read_json( $opt, $old_history_file ) // {};
             for my $url ( keys %{$opt->{history}} ) {
                 $opt->{history}{$url}{uploader}    =         delete $opt->{history}{$url}{channel}       if $opt->{history}{$url}{channel};
                 $opt->{history}{$url}{uploader_id} =         delete $opt->{history}{$url}{channel_id}    if $opt->{history}{$url}{channel_id};
